===========
lfdocs_conf
===========

.. _lfdocs_conf_v0.7.6:

v0.7.6
======

.. _lfdocs_conf_v0.7.6_Bug Fixes:

Bug Fixes
---------

.. releasenotes/notes/funcparserlib-1.0.0a0-update-136147c73bcd069c.yaml @ b'6c95d55f71575c7824bc87527e94939d9e4aa8da'

- Update funcparserlib for better compatibility with Sphinx
  version 4.2.0. This and other libraries are needed to generate
  ONAP's docs.


.. _lfdocs_conf_v0.7.3:

v0.7.3
======

.. _lfdocs_conf_v0.7.3_Bug Fixes:

Bug Fixes
---------

.. releasenotes/notes/fix-onap-copyright-notice-89415a353ed2a2be.yaml @ b'6f29096bb5037824b6a89d7e7c54f746fb55ad10'

- Remove redundant "copyright" word from ONAP copyright notice.
  (LF JIRA: RELENG-3929).
  
  Ref:
    https://wiki.onap.org/display/Meetings/TSC+2021-08-05


.. _lfdocs_conf_v0.7.2:

v0.7.2
======

.. _lfdocs_conf_v0.7.2_Other Notes:

Other Notes
-----------

.. releasenotes/notes/update-onap-copyright-notice-aa41dcab260a5e5b.yaml @ b'9bdb84d6817a759875417591d1910aaa2ce1bbd9'

- Update ONAP copyright notice as approved by ONAP TSC.
  (LF JIRA: RELENG-3840).
  
  Ref:
    https://wiki.onap.org/display/Meetings/TSC+2021-08-05


.. _lfdocs_conf_v0.7.1:

v0.7.1
======

.. _lfdocs_conf_v0.7.1_Other Notes:

Other Notes
-----------

.. releasenotes/notes/update-onap-copyright-9debb4772e6d3339.yaml @ b'89d6d5e85b4a7fc342223716adba4e4f1ad2c649'

- Change ONAP copyright notice. (LF JIRA: RELENG-3840).


.. _lfdocs_conf_v0.7.0:

v0.7.0
======

.. _lfdocs_conf_v0.7.0_Other Notes:

Other Notes
-----------

.. releasenotes/notes/conventional_commit-5cbbd021edc324c2.yaml @ b'2b9411e8831f17cfc0ad46a91886df4dcfdf04ad'

- Conventional Commit message subject lines are now enforced. This affects
  CI. Additionally, if developers want to protect themselves from CI failing
  on this please make sure of the following
  
  * you have pre-commit installed
  * that you have run
    pre-commit install --hook-type commit-msg


.. _lfdocs_conf_v0.6.0:

v0.6.0
======

.. _lfdocs_conf_v0.6.0_Upgrade Notes:

Upgrade Notes
-------------

.. releasenotes/notes/sphinx-3.2-8e24c17b03786cfd.yaml @ b'a9582a78dc4fc483205ccb1cda4a58a21f690bca'

- Sphinx has been upgraded to 3.2.x.

.. releasenotes/notes/unpin-more-itertools-5dff9b6955769e99.yaml @ b'de2a88d3f717d49863d524a2a6be4fe189bae2fb'

- If using Python 3.4 or newer, more-itertools is no longer pinned to the 5.x
  release.


.. _lfdocs_conf_v0.6.0_Bug Fixes:

Bug Fixes
---------

.. releasenotes/notes/remove-pytest-dep-8a0d427bfcd1f5c3.yaml @ b'caa0ac6dd799b3f782d6958001cbf8394a29e4f8'

- Pytest is no longer pulled in as a dependency of docs-conf.


.. _lfdocs_conf_v0.5.0:

v0.5.0
======

.. _lfdocs_conf_v0.5.0_New Features:

New Features
------------

.. releasenotes/notes/support-sphinx-tabs-7a9e3e9ed2a7795a.yaml @ b'eb1f1edbd595c8fdbe25e9b693030e95fec38816'

- Add support for sphinx-tabs (https://github.com/djungelorm/sphinx-tabs).


.. _lfdocs_conf_v0.5.0_Upgrade Notes:

Upgrade Notes
-------------

.. releasenotes/notes/update-sphinx-3.0.4-c023706bfba48a52.yaml @ b'd3cc1c40f6d0827686d34387d99f0d450ff4b84d'

- Updates Sphinx from ~2.3.1 to ~3.0.4 which may or may not affect
  project docs build. Refer to upstream release note as necessary.
  https://www.sphinx-doc.org/en/master/changes.html


.. _lfdocs_conf_v0.3.0:

v0.3.0
======

.. _lfdocs_conf_v0.3.0_Upgrade Notes:

Upgrade Notes
-------------

.. releasenotes/notes/sphinx-update-6b451b2462799591.yaml @ b'c86baade9f3d38e9664bb617b9ea80ca01ac895e'

- Sphinx version is updated from ~1.7.9 to ~1.8.5 which may or may not affect
  project docs build. Refer to upstream release note as necessary.
  https://www.sphinx-doc.org/en/master/changes.html

